@@ -6,7 +6,7 @@ test_that("glm vs. Stata", {
     dat <- read.csv(test_path("stata/databases/stats_glm_01.csv"))
     mod <- speedglm(y ~ x1 * x2, family = binomial(), data = dat)
     mfx <- merge(tidy(marginaleffects(mod)), stata)
-    expect_mfx(mod)
+    expect_marginaleffects(mod)
     expect_equal(mfx$estimate, mfx$dydxstata, tolerance = .00001)
     expect_equal(mfx$std.error, mfx$std.errorstata, tolerance = .0001)
 })
@@ -17,7 +17,7 @@ test_that("lm vs. Stata", {
     dat <- read.csv(test_path("stata/databases/stats_lm_01.csv"))
     mod <- speedlm(y ~ x1 * x2, data = dat)
     mfx <- merge(tidy(marginaleffects(mod)), stata)
-    expect_mfx(mod)
+    expect_marginaleffects(mod)
     expect_equal(mfx$estimate, mfx$dydxstata, tolerance = .00001)
     expect_equal(mfx$std.error, mfx$std.errorstata, tolerance = .0001)
 })
