@@ -10,7 +10,7 @@ test_that("coxph vs. Stata", {
                  data = test1,
                  ties = "breslow")
     mfx <- merge(tidy(marginaleffects(mod, type = "lp")), stata)
-    expect_mfx(mod, type = "risk", n_unique = 4)
+    expect_marginaleffects(mod, type = "risk", n_unique = 4)
     expect_equal(mfx$estimate, mfx$dydxstata)
     expect_equal(mfx$std.error, mfx$std.errorstata)
 })
@@ -22,11 +22,11 @@ test_that("coxph: no validity", {
                   event=c(1,1,1,1,1,1,1,0,0,0), 
                   x=c(1,0,0,1,0,1,1,1,0,0)) 
     mod <- coxph(Surv(start, stop, event) ~ x, test2)
-    expect_mfx(mod, type = "risk", n_unique = 2)
+    expect_marginaleffects(mod, type = "risk", n_unique = 2)
 
     mod <- coxph(Surv(time, status) ~ ph.ecog + tt(age), data=lung,
                  tt=function(x,t,...) pspline(x + t/365.25))
-    expect_mfx(mod, type = "risk")
+    expect_marginaleffects(mod, type = "risk")
 })
 
 
